@@ -1,9 +1,12 @@
 """Config parser for Buildout Versions Checker"""
+import re
 try:
     from ConfigParser import RawConfigParser
 except ImportError:  # Python 3
     from configparser import RawConfigParser
 
+OPERATORS = re.compile(r'[+-<]$')
+
 
 class VersionsConfigParser(RawConfigParser):
     """
@@ -19,13 +22,22 @@ class VersionsConfigParser(RawConfigParser):
         """
         string_section = '[%s]\n' % section
         for key, value in self._sections[section].items():
-            if key != '__name__':
-                if value is None:
-                    value = ''
-                string_section += '%s= %s\n' % (
-                    key.ljust(indentation),
-                    str(value).replace(
-                        '\n', '\n'.ljust(indentation + 3)))
+            if key == '__name__':
+                continue
+            if value is None:
+                value = ''
+            operator = ''
+            key_indentation = indentation
+            buildout_operator = OPERATORS.search(key)
+            if buildout_operator:
+                operator = buildout_operator.group(0)
+                key_indentation -= 1
+                key = key[:-1]
+            key = key.ljust(key_indentation) + operator
+            value = str(value).replace('\n', '\n'.ljust(
+                key_indentation + 3 + int(bool(operator))))
+            string_section += '%s= %s\n' % (key, value)
+
         fd.write(string_section.encode('utf-8'))
 
     def write(self, source, indentation=32):
